@@ -1,7 +1,7 @@
 package Log::ger::App;
 
-our $DATE = '2017-07-14'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $DATE = '2017-09-07'; # DATE
+our $VERSION = '0.004'; # VERSION
 
 # IFUNBUILT
 # use strict;
@@ -100,6 +100,11 @@ sub import {
         };
     }
 
+    if ($args{outputs}) {
+        $conf{outputs}{$_} = $args{outputs}{$_}
+            for keys %{$args{outputs}{$_}};
+    }
+
     require Log::ger::Output;
     Log::ger::Output->set('Composite', %conf);
 }
@@ -119,16 +124,26 @@ Log::ger::App - An easy way to use Log::ger in applications
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
+In your script:
+
  use Log::ger::App;
+ use Your::App::Module; # your module which uses Log::ger to do its logging
+
+If you also do logging in your script:
+
+ use Log::ger::App;
+ use Log::ger;
+
+ log_warn("Some log ...");
 
 =head1 DESCRIPTION
 
-This module sets up sensible defaults for L<Log::ger::Output::Composite> from
-the environment variables.
+This module basically loads L<Log::ger::Output::Composite> with some sensible
+defaults and allows customizing some aspects via environment variable.
 
 B<Outputs:>
 
@@ -139,14 +154,16 @@ B<Outputs:>
  Script running as root          y       /var/log/PROGNAME.log  -
  Daemon                          -       /var/log/PROGNAME.log  y
 
-B<General log level:> the default is warn (like L<Log::ger>'s default). You can
-set it from environment using L<LOG_LEVEL> (e.g. C<LOG_LEVEL=trace> to set level
-to trace or L<LOG_LEVEL=0> to turn off logging). Alternatively, you can set to
-trace using C<TRACE=1>, or debug with C<DEBUG=1>, info with C<VERBOSE=1>, error
-with C<QUIET=1>.
+B<General log level:> the default is C<warn> (like L<Log::ger>'s default). You
+can set it from environment using L<LOG_LEVEL> (e.g. C<LOG_LEVEL=trace> to set
+level to trace or L<LOG_LEVEL=0> to turn off logging). Alternatively, you can
+set to C<trace> using C<TRACE=1>, or C<debug> with C<DEBUG=1>, C<info> with
+C<VERBOSE=1>, C<error> with C<QUIET=1>.
 
 B<Per-output level:> the default is to use general level, but you can set a
-different level using I<OUTPUT_NAME>_{C<LOG_LEVEL|TRACE|DEBUG|VERBOSE|QUIET>}.
+different level using I<OUTPUT_NAME>_{C<LOG_LEVEL|TRACE|DEBUG|VERBOSE|QUIET>}
+variables. For example, C<SCREEN_DEBUG=1> to set screen level to C<debug> or
+C<FILE_LOG_LEVEL=off> to turn off file logging.
 
 =head1 FUNCTIONS
 
@@ -158,7 +175,8 @@ Arguments:
 
 =item * level => str|num
 
-Explicitly set level.
+Explicitly set level. Otherwise, the default will be taken from environment
+variable like described previously in L</"DESCRIPTION">.
 
 =item * name => str
 
@@ -172,6 +190,11 @@ Otherwise, Log::ger::App will try some heuristics to guess whether your
 application is a daemon: from the value of C<$main::IS_DAEMON> and from the
 presence of modules like L<HTTP::Daemon>, L<Proc::Daemon>, etc.
 
+=item * outputs => hash
+
+Specify extra outputs. Will be passed to L<Log::ger::Output::Composite>
+configuration.
+
 =back
 
 =head1 ENVIRONMENT
